@@ -1,5 +1,6 @@
 from typing import TYPE_CHECKING
 from typing import List
+from typing import Optional
 
 import pendulum
 
@@ -27,7 +28,7 @@ class Calendar:
 
         return []
 
-    def events_between(self, start: "DateTime", end: "DateTime") -> List[str]:
+    def events_between(self, start: "DateTime", end: "DateTime") -> List["Event"]:
         """Yields all events between start and end."""
         events = self._events
 
@@ -37,3 +38,8 @@ class Calendar:
                 events_between.append(event)
 
         return events_between
+
+    def event(self, name: str) -> Optional["Event"]:
+        for event in self._events:
+            if event.name == name:
+                return event
