@@ -1,3 +1,4 @@
+from ctypes import Union
 from dataclasses import dataclass
 from typing import Dict
 from typing import List
@@ -9,6 +10,7 @@ from wheat.calendar.attendee import Attendee
 
 @dataclass
 class Event:
+    id: str
     name: str
     creator: Attendee
     start: datetime
@@ -33,6 +35,26 @@ class Event:
         """The integer day of the month that the event occurs."""
         return self.start.day
 
+    @property
+    def tagged(self) -> bool:
+        """True if this event has an associated task short."""
+        return self.short and isinstance(self.short, str)
+            
+    @property
+    def short(self) -> str:
+        """The Task short related to this event, if one exists."""
+        return self.labels.get("short")
+
+    def compact(self) -> List[str]:
+        start = self.start.to_day_datetime_string()
+        end = self.end.to_day_datetime_string()
+        pretty_event = (
+            f"Meeting:      {self.name} - {self.creator.email}",
+            f"Creator:      {start} -> {end}",
+        )
+        
+        return pretty_event
+
     def __lt__(self, other: "Event") -> bool:
         return self.start <= other.start
 
@@ -42,13 +64,21 @@ class Event:
         # a column that displays nicely in the terminal.
         # This sort method is consistent with the google
         # calendar interface.
-        attendees = map(str, sorted(self.attendees))
+        attendees = list(map(str, sorted(self.attendees)))
+        if len(attendees) > 7:
+            remaining = len(attendees) - 7
+            attendees = attendees[:7]
+            attendees.append(f"   + {remaining} more.")
+
         attendees = "\n              ".join(attendees)
+
+        start = self.start.to_day_datetime_string()
+        end = self.end.to_day_datetime_string()
         pretty_event = (
             f"Meeting Name: {self.name}\n"
             f"Creator:      {self.creator.email}\n"
-            f"Starts At:    {self.start}\n"
-            f"Ends At:      {self.end}\n"
+            f"Starts At:    {start}\n"
+            f"Ends At:      {end}\n"
             f"Attendees:    {attendees}\n"
             f"Zoom Link:    {self.zoom_link}\n"
         )
