@@ -1,4 +1,5 @@
 from pathlib import Path
+from pprint import pprint
 from typing import TYPE_CHECKING
 from typing import Any
 from typing import Dict
@@ -79,6 +80,19 @@ def get_events_in_interval(
 
     return [_process_event_description(desc) for desc in event_descriptions]
 
+def patch_event(
+    service: Any, event_id: str, properties = Dict[str, Any]
+) -> Event:
+    parameters = dict(
+        calendarId="primary",
+        eventId=event_id,
+        extendedProperties={"private": properties, "shared": {}}
+    )
+    
+    body = {"extendedProperties": {"private": properties, "shared": {}}}
+    query = service.events().patch(**parameters)
+    event_descriptions = query.execute().get("items", [])
+    return [_process_event_description(desc) for desc in event_descriptions]
 
 def _process_event_description(description: Dict[str, Any]) -> Event:
     """Processes a google calendar event description.
@@ -95,7 +109,7 @@ def _process_event_description(description: Dict[str, Any]) -> Event:
 
     def datetime_string(dt: "DateTime", tz: str) -> str:
         """Converts a datetime object to a string."""
-        return pendulum.parse(dt, tz=tz).to_day_datetime_string()
+        return pendulum.parse(dt, tz=tz)
 
     start = datetime_string(
         description["start"]["dateTime"], description["start"]["timeZone"]
@@ -118,6 +132,8 @@ def _process_event_description(description: Dict[str, Any]) -> Event:
         if link:
             entry_link = link
             break
+    
+    labels = description.get("extendedProperties", {}).get("private", {})
 
     # Look for a zoom link in these four locations, in order.
     # if none is found, use a 'not found' string.
@@ -129,11 +145,12 @@ def _process_event_description(description: Dict[str, Any]) -> Event:
     )
 
     return Event(
+        id=description["id"],
         name=description["summary"],
         creator=Attendee(email=description["creator"].get("email", "Unknown")),
         start=start,
         end=end,
         attendees=attendees,
-        labels=description.get("labels", {}),
+        labels=labels,
         zoom_link=zoom_link,
     )
