@@ -2,6 +2,7 @@ from pathlib import Path
 from typing import Any
 from typing import Optional
 from typing import Tuple
+from xmlrpc.client import DateTime
 
 import pendulum
 
@@ -10,6 +11,7 @@ from tomlkit.toml_file import TOMLFile
 from wheat.__version__ import __version__
 from wheat.calendar.calendar import Calendar
 from wheat.calendar.google import create_google_calendar_service
+from wheat.calendar.google import create_or_find_existing_google_credentials
 from wheat.calendar.google import get_events_in_interval
 from wheat.harvest.harvest import Harvest
 from wheat.harvest.harvest_client import HarvestClient
@@ -20,13 +22,17 @@ class Factory:
     def __init__(self, io: IO) -> None:
         self.io = io
 
-    def create_google_calendar(self, service: Optional[Any] = None) -> Calendar:
+    def create_google_calendar_service(self) -> Any:
+        credentials = create_or_find_existing_google_credentials()
+        return create_google_calendar_service(credentials)
+    
+    def create_google_calendar(self, service: Optional[Any] = None, start: Optional[DateTime] = None, end: Optional[DateTime] = None) -> Calendar:
         if service is None:
-            service = create_google_calendar_service()
+            service = self.create_google_calendar_service()
 
         now = pendulum.now()
-        start = now.first_of("month").to_iso8601_string()
-        end = now.last_of("month").to_iso8601_string()
+        start = (start or now.first_of("month")).to_iso8601_string()
+        end = (end or now.last_of("month")).to_iso8601_string()
         return Calendar(get_events_in_interval(service, start, end))
 
     def create_harvest(self, api: Optional[HarvestClient] = None) -> Optional[Harvest]:
@@ -57,7 +63,12 @@ class Factory:
         return id, token
 
     def create_harvest_credentials(self, account_id: str, token: str) -> Path:
-        path = Path(CONFIG_DIR) / "harvest_credentials.toml"
+        config_dir = Path(CONFIG_DIR)
+        
+        if not config_dir.exists():
+            config_dir.mkdir(exist_ok=True, parents=True)
+
+        path = config_dir / "harvest_credentials.toml"
 
         if not path.exists():
             mode = 0o600  # Ensure only user can access the file.
