@@ -1,4 +1,4 @@
 from wheat.utils.appdirs import user_config_dir
 
 
-CONFIG_DIR = user_config_dir("foresight")
+CONFIG_DIR = user_config_dir("wheat")
